@@ -599,7 +599,6 @@ create_style_toolbar (GtkHTMLControlData *cd)
 {
 	GtkWidget *hbox;
 	gchar *domain;
-	gchar *filename;
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 
@@ -623,9 +622,8 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	 */
 	domain = g_strdup (textdomain (NULL));
 	textdomain (GETTEXT_PACKAGE);
-	
-	filename = g_build_filename (GTKHTML_DATADIR, "icons", "font-tt-24.png", NULL);
-	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].pixmap_info = filename;
+
+	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_TT].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text-monospaced", 24, NULL, NULL);
 	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_BOLD].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_bold", 24, NULL, NULL);
 	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_ITALIC].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_italic", 24, NULL, NULL);
 	editor_toolbar_style_uiinfo [EDITOR_TOOLBAR_UNDERLINE].pixmap_info = gnome_icon_theme_lookup_icon (cd->icon_theme, "stock_text_underlined", 24, NULL, NULL);
